#ifndef SYMFONIEINFOWINDOW_H
#define SYMFONIEINFOWINDOW_H

#include <QWidget>
#include <QVBoxLayout>
#include <phonon>

class SymfonieMediaPlayer;

class SymfonieInfoWindow : public QWidget
{
Q_OBJECT
public:
    explicit SymfonieInfoWindow(SymfonieMediaPlayer* player, QWidget *parent = 0);

signals:

public slots:

private:
  QVBoxLayout *layout;
  Phonon::SeekSlider *seekSlider;
  SymfonieMediaPlayer *player;
};

#endif // SYMFONIEINFOWINDOW_H
